{ pkgs, ... }: 

{
  	services."06cb-009a-fingerprint-sensor" = {
    	enable = true;
    	backend = "python-validity";
    	calib-data-file = ./calib-data.bin;
  	};

  	services.greetd-hyprland.enable = true;
  	services.nvidia.enable = true;
  	services.fingerprint-fix.enable = true;

  	services.fprintd.enable = pkgs.lib.mkForce true;

  	services.upower.enable = true;
  	services.udev.enable = true;
  	services.udev.packages = [ pkgs.hyprland ];

  	services.printing = {
    	enable = true;
    	drivers = with pkgs; [ hplipWithPlugin ];
  	};

	security.rtkit.enable = true;
	services.pipewire = {
  		enable = true;
  		alsa.enable = false;
  		alsa.support32Bit = true;
  		pulse.enable = true;
  		jack.enable = true;
		extraConfig.pipewire.context.properties = {
			default.clock.allowed-rates = [ 44100 48000 96000 ];
			log.level = 4;
			default.clock.quantum       = 256;
			default.clock.min-quantum   = 256;
			default.clock.max-quantum   = 256;
    	};
	};

	systemd.services.bluetooth.serviceConfig.ExecStart = pkgs.lib.mkForce [
  		""
  		"${pkgs.bluez}/libexec/bluetooth/bluetoothd -f /etc/bluetooth/main.conf -C"
	];

	hardware.bluetooth.enable = true;
	hardware.bluetooth.powerOnBoot = true;

	services.blueman.enable = true;

	services.gvfs.enable = true;
	services.tlp = {
      	enable = true;
      	settings = {
       		START_CHARGE_THRESH_BAT0 = 40;
       		STOP_CHARGE_THRESH_BAT0 = 80;
		};
	};
}
